# PeakSQL

[![Maintainability](https://api.codeclimate.com/v1/badges/d5f1443a164eb0d64d33/maintainability)](https://codeclimate.com/github/vanheeringen-lab/peaksql/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/d5f1443a164eb0d64d33/test_coverage)](https://codeclimate.com/github/vanheeringen-lab/peaksql/test_coverage)
![ContinuousIntegration](https://github.com/vanheeringen-lab/peaksql/workflows/ContinuousIntegration/badge.svg)
![ContinuousDeployment](https://github.com/vanheeringen-lab/peaksql/workflows/ContinuousDeployment/badge.svg)
